@@ -25,31 +25,6 @@ Configuration file containing the set of sources and
 relations to use. The default uses MSH and the PAR/CHD 
 relations.
 
-The format of the configuration file is as follows:
-
-SAB :: <include|exclude> <source1, source2, ... sourceN>
-
-REL :: <include|exclude> <relation1, relation2, ... relationN>
-
-RELA :: <include|exclude> <rela1, rela2, ... relaN>  (optional)
-
-The SAB, REL and RELA are for specifing what sources and relations 
-should be used when traversing the UMLS. For example, if we 
-wanted to use the MSH vocabulary with only the RB/RN relations, 
-the configuration file would be:
-
-SAB :: include MSH
-REL :: include RB, RN
-RELA :: include isa, inverse_isa
-
-or if we wanted to use MSH and use any relation except for PAR/CHD, 
-the configuration would be:
-
-SAB :: include MSH
-REL :: exclude PAR, CHD
-
-An example of the configuration file can be seen in the samples/ directory. 
-
 =head2 Optional Arguments:
 
 =head3 --debug
@@ -78,10 +53,11 @@ The socket your mysql is using. DEFAULT: /tmp/mysql.sock
 
 Database contain UMLS DEFAULT: umls
 
-=head3 --debugpath FILE
+=head3 --verbose FILE
+
+Stores the path information for each of the concepts 
+in FILE during the DFS
 
-This option prints out the path information for debugging 
-purposes. 
 
 =head3 --depth NUMBER
 
@@ -93,10 +69,6 @@ search the complete hierarchy
 Starts the search at a specified CUI. The default starts 
 the search at the UMLS root node
 
-=head3 --level NUMBER
-
-Returns the number of CUIs above and below this NUMBER
-
 =head3 --help
 
 Displays the quick summary of program options.
@@ -118,7 +90,6 @@ The program returns the following:
     7. number of nodes
     8. root
 
-
 =head1 SYSTEM REQUIREMENTS
 
 =over
@@ -178,7 +149,7 @@ this program; if not, write to:
 use UMLS::Interface;
 use Getopt::Long;
 
-eval(GetOptions( "version", "help", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "depth=s", "root=s", "debugpath=s", "debug", "level=s")) or die ("Please check the above mentioned option(s).\n");
+GetOptions( "version", "help", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "depth=s", "root=s", "verbose=s", "debug");
 
 
 
@@ -244,25 +215,13 @@ if(defined $opt_socket) {
 
 $umls = UMLS::Interface->new(\%option_hash); 
 die "Unable to create UMLS::Interface object.\n" if(!$umls);
+($errCode, $errString) = $umls->getError();
+die "$errString\n" if($errCode);
 
-#  get the relations from the configuration file
-my $configrel = $umls->getRelString();
-$configrel=~/(REL) (\:\:) (include|exclude) (.*?)$/;
-my $relationstring = $4; 
-
-#  check to make certain the configuration file only contains
-#  heirarchical relations (PAR/CHD or RB/RN).
-my @relations = split/\s*\,\s*/, $relationstring; 
-foreach my $rel (@relations) { 
-  if(! ($rel=~/(PAR|CHD|RB|RN)/) ) { 
-    print STDERR "The findDFS.pl program only supports heirarchical relations (PAR/CHD or RB/RN).\n";
-    &minimalUsageNotes();
-    exit;
-  } 
-}
+&errorCheck($umls);
 
 #  set the root
-my $root = "C0000000";
+my $root = "C0085567";
 if(defined $opt_root) {
     $root = $opt_root;
 }
@@ -292,14 +251,15 @@ while(<CONFIG>) {
     }
 }
 
-#  if the debugpath option is turned on open up the table file
-if($opt_debugpath) {
+#  if the verbose option is turned on open up the table file
+if($opt_verbose) {
     
-    open(TABLEFILE, ">$opt_debugpath") || die "Could not open $opt_debugpath";
+    open(TABLEFILE, ">$opt_verbose") || die "Could not open $opt_verbose";
 }
 
-#  get the first set of children and start the dfs
-my @children= $umls->getChildren($root); 
+#  get the first set of children and start the 
+my @children= $umls->_getChildrenForDFS($root); 
+&errorCheck($umls);
 
 #  update the branching variables
 $max_branch = $#children + 1;
@@ -309,7 +269,6 @@ foreach my $child (@children) {
     my @array = (); 
     push @array, $root;
     my $path  = \@array;
-    my $d = 0;
     &_depthFirstSearch($child, $d, $path,*TABLEFILE);
 }
 
@@ -322,7 +281,7 @@ else {
 }
 
 #  close the file and set the permissions
-if($opt_debugpath) {
+if($opt_verbose) {
     close TABLEFILE;
     my $temp = chmod 0777, $tableFile;
 }
@@ -338,82 +297,23 @@ $avg_branch = $avg_branch / $branch_counter;
 #  set the node and leaf counts
 my $leaf_count = keys %leafs;
 my $node_count = keys %nodes;
-my $total_count = $leaf_count + $node_count;
 
-#  get the average depth
-my $avg_leaf_depth = 0; my $avg_node_depth = 0;
-foreach my $c (sort keys %leafs) { $avg_leaf_depth+=$leafs{$c}; }
-foreach my $c (sort keys %nodes) { $avg_node_depth+=$nodes{$c}; }
 
-my $avg_depth = ($avg_leaf_depth + $avg_node_depth) / $total_count;
-if($leaf_count > 0) { 
-    $avg_leaf_depth = $avg_leaf_depth / $leaf_count;
-}
-if($node_count > 0) { 
-    $avg_node_depth = $avg_node_depth / $node_count;
-}
 
-#  get the standard deviation
-my $avg_leaf_sd = 0; $avg_node_sd = 0;
-foreach my $c (sort keys %leafs) { $avg_sd += ($leafs{$c}-$avg_depth)**2; }
-foreach my $c (sort keys %nodes) { $avg_sd += ($nodes{$c}-$avg_depth)**2; }
-
-$avg_sd = $avg_sd/$total_count;
-$avg_sd = sqrt($avg_sd); 
-
-#  get the mean depth of the leafs and nodes
-#  also get the --level information if defined
-my $leaf_mean = int($leaf_count / 2);
-my $node_mean = int($node_count / 2);
-
-my $leaf_mean_depth  = 0;
-my $node_mean_depth  = 0;
-my $level_leaf_above = 0;
-my $level_leaf_below = 0;
-my $level_node_above = 0;
-my $level_node_below = 0;
-my $counter          = 1;
-
-foreach my $c (sort {$leafs{$b}<=>$leafs{$a}} keys %leafs) { 
-    if($counter == $leaf_mean) { 
-	$leaf_mean_depth = $leafs{$c};
-    }
-    if($leafs{$c} >= $opt_level) { $level_leaf_above++; }
-    if($leafs{$c} <  $opt_level) { $level_leaf_below++; }
-    $counter++; 
-}
-
-$counter = 1;
-foreach my $c (sort {$nodes{$b}<=>$nodes{$a}} keys %nodes) { 
-    if($counter == $node_mean) { 
-	$node_mean_depth = $nodes{$c};
-    }
-    if($nodes{$c} >= $opt_level) { $level_node_above++; }
-    if($nodes{$c} <  $opt_level) { $level_node_below++; }
-    $counter++; 
-}
-    
 #  print out the information
 print "max_depth : $max_depth\n";
-print "avg_depth : $avg_depth\n";
-print "sd_depth  : $avg_sd\n";
 print "paths_to_root : $paths_to_root\n";
 print "sources : $sources\n";
 print "max_branch : $max_branch\n";
 print "avg_branch : $avg_branch\n";
 print "leaf_count : $leaf_count\n";
 print "node_count : $node_count\n";
-print "avg_leaf_depth : $avg_leaf_depth\n";
-print "avg_node_depth : $avg_node_depth\n";
-print "mean_leaf_depth : $leaf_mean_depth\n";
-print "mean_node_depth : $node_mean_depth\n";
-print "root : $root\n"; 
-if(defined $opt_level) { 
-    print "nodes_above_level : $level_node_above\n";
-    print "leafs_above_level : $level_leaf_above\n";
-    print "nodes_below_level : $level_node_below\n";
-    print "leafs_below_level : $level_leaf_below\n";
-}
+print "root : $root\n";
+
+
+#foreach my $b (sort {$a<=>$b} keys %branch_hash) {
+#    print "$b: $branch_hash{$b}\n";
+#}
 
 ######################################################################### 
 #  Depth First Search (DFS) 
@@ -450,23 +350,21 @@ sub _depthFirstSearch
     if($concept=~/C1274015/) { return; }
     #C1274021|Moved elsewhere (inactive concept)
     if($concept=~/C1274021/) { return; }
-    #C2733115|limited status concept
-    if($concept=~/C2733115/) { return 1; }
-    
+
     #  set the new path
     my @path = @{$array};
     push @path, $concept;
     
     my $series = join " ", @path;
     
-    #  print information into the file if debugpath option is set
-    if($opt_debugpath) { print F "$concept\t$d\t$series\n"; }
+    #  print information into the file if verbose option is set
+    if($opt_verbose) { print F "$concept\t$d\t$series\n"; }
     
     #  increment the number of paths
     $paths_to_root++;
 
     #  get all the children
-    my @children = $umls->getChildren($concept);
+    my @children = $umls->_getChildrenForDFS($concept);
 
     
     my $branches = 0;
@@ -493,22 +391,22 @@ sub _depthFirstSearch
 	$branch_hash{$concept} = $branches;
     }
     
-    #  set the leaf count and capture the max depth
-    if($branches == 0) { 
-	if(exists $leafs{$concept}) { 
-	    if($d > $leafs{$concept}) { 
-		$leafs{$concept} = $d; 
-	    } 
-	} else { $leafs{$concept} = $d; }
-    }
-    else {
-	if(exists $nodes{$concept}) { 
-	    if($d > $nodes{$concept}) { 
-		$nodex{$concept} = $d; }
-	}
-	else { $nodes{$concept} = $d; }
-    }
+    #  set the leaf count
+    if($branches == 0) { $leafs{$concept}++; }
+    else               { $nodes{$concept}++; }
 }
+
+##############################################################################
+#  error check
+##############################################################################
+sub errorCheck
+{
+    my $obj = shift;
+    ($errCode, $errString) = $obj->getError();
+    print STDERR "$errString\n" if($errCode);
+    exit if($errCode > 1);
+}
+
 ##############################################################################
 #  function to output minimal usage notes
 ##############################################################################
@@ -545,14 +443,11 @@ sub showHelp() {
     
     print "--socket STRING          Socket used by mysql (DEFAULT: /tmp.mysql.sock)\n\n";
 
-    print "--debugpath FILE         Stores path information in FILE\n\n";
+    print "--verbose FILE           Stores path information in FILE\n\n";
     
     print "--depth NUMBER           Searches up to the specified depth\n";
     print "                         Default searches the complete taxonomy\n\n";
-
-    print "--level NUMBER           Returns the number of CUIs above and \n";
-    print "                         below this NUMBER.\n\n";
-
+    
     print "--root CUI               Starts the search at a specified CUI\n";
     print "                         Default is the UMLS root\n\n";
     
@@ -565,7 +460,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: findDFS.pl,v 1.21 2010/10/08 19:26:04 btmcinnes Exp $';
+    print '$Id: findDFS.pl,v 1.2 2010/01/20 16:28:31 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
